from setuptools import setup

setup(name='hgftg',
version='1.9',
description='This PIP only made for designing Tool and Termux Bennar',
author='cracker911181',
url='https://github.com/cracker911181/cracker_say',
packages=['cracker_say'],

zip_safe=False)
